@@ -5,9 +5,14 @@ from django.core.cache import InvalidCacheBackendError
 
 log = logging.getLogger(__name__)
 
-COUCH_CACHE_TIMEOUT = 43200
+COUCH_CACHE_TIMEOUT = 60 * 60 * 12
 MOCK_REDIS_CACHE = None
 
+try:
+    REDIS_CACHE = cache.get_cache('redis')
+except:
+    REDIS_CACHE = None
+
 DEBUG_TRACE = False
 
 CACHE_DOCS = getattr(settings, 'COUCH_CACHE_DOCS', False)
@@ -36,11 +41,17 @@ def get_redis_default_cache():
     except (InvalidCacheBackendError, ValueError):
         return cache.cache
 
+
 def get_redis_client():
-    from redis_cache.cache import RedisCache
-    rcache = get_redis_default_cache()
+    if not REDIS_CACHE:
+        raise RedisClientError("No redis cache defined in settings")
+
     try:
-        client = rcache.raw_client
+        try:
+            client = REDIS_CACHE.raw_client
+        except AttributeError:
+            # version >= 3.8.0
+            client = REDIS_CACHE.client.get_client()
     except Exception:
         log.error("Could not get redis connection.", exc_info=True)
         raise RedisClientError("Could not get redis connection.")
