@@ -47,7 +47,7 @@ class GenerationCache(object):
     def _get_generation(self):
         genret = rcache().get(self.generation_key, None)
         if not genret:
-            #never seen key before, start from zero
+            # never seen key before, start from zero
             rcache().set(self.generation_key, 0, timeout=0)
             return str(0)
         else:
@@ -57,8 +57,11 @@ class GenerationCache(object):
         """
         Invalidate this cache by incrementing the generation
         """
-        current_generation = self._get_generation()
-        return rcache().incr(self.generation_key)
+        try:
+            return rcache().incr(self.generation_key)
+        except ValueError:
+            # there was likely no cached data to start with. that's fine.
+            pass
 
     def _mk_view_cache_key(self, view_name, params=None):
         """
@@ -114,7 +117,6 @@ class GenerationCache(object):
             cached_view = INTERRUPTED
 
         is_cache_hit = cached_view not in (MISSING, INTERRUPTED) and CACHE_VIEWS
-
         if include_docs:
             # include_docs=True results in couchdbkit remove the 'rows' result
             # and returns just the actual rows in an array
@@ -148,6 +150,8 @@ class GenerationCache(object):
             else:
                 # cache miss, get view, cache it and all docs
                 view_obj = db.view(view_name, **params)
+                # todo: we should try and decouple this from the "protected" methods of
+                # couchdbkit's ViewResults
                 view_obj._fetch_if_needed()
                 view_results = view_obj._result_cache
                 row_stubs = []
@@ -162,8 +166,8 @@ class GenerationCache(object):
                     row_stubs.append(stub)
 
                 cached_results = {
-                    "total_rows": view_results['total_rows'],
-                    "offset": view_results['offset'],
+                    "total_rows": view_obj._total_rows,
+                    "offset": view_obj._offset,
                     "row_stubs": row_stubs
                 }
 
