@@ -143,10 +143,10 @@ class IteratorJSONReader(object):
                     'false': False,
                     '': False,
                     None: False,
-                }[value]
-            except AttributeError:
+                }[value.lower() if hasattr(value, 'lower') else value]
+            except KeyError:
                 raise JSONReaderError(
-                    'Values for %s must be: "yes" or "no" (or empty = "no")'
+                    'Values for %s must be: "yes" or "no" (or empty = "no")' % field
                 )
 
         # set for any flat type
@@ -281,4 +281,4 @@ def alphanumeric_sort_key(key):
     """
     import re
     convert = lambda text: int(text) if text.isdigit() else text
-    return [convert(c) for c in re.split('([0-9]+)', key)]
\ No newline at end of file
+    return [convert(c) for c in re.split('([0-9]+)', key)]
