@@ -10,5 +10,6 @@ __test__ = {
     'create_unique_filter': create_unique_filter,
 }
 
-from lazy_attachment_doc import *
-from dates import *
\ No newline at end of file
+from .lazy_attachment_doc import *
+from .dates import *
+from .test_json_handler import *
